#include <iostream>
#include <string>
#include <cstdio>
#include <cstring>
#include <algorithm>
#include <vector>
#include <map>
#include <sstream>

using namespace std;

#define LOGVP(v) for (auto e : v) { cout << "(" << e.x << ", " << e.y << ") "; }
#define LOGV(v) for (auto e : v) {cout << e << " "; }

struct pnt {
    int x, y;

    pnt(int x = 0, int y = 0): x(x), y(y) {}

    pnt operator+ (pnt other) {
        return pnt(x + other.x, y + other.y);
    }

    pnt operator* (int k) {
        return pnt(x * k, y * k);
    }

    pnt& operator+= (pnt other) {
        x += other.x;
        y += other.y;
        return *this;
    }

    bool operator== (pnt other) {
        return other.x == x && other.y == y;
    }

    friend ostream& operator<< (ostream& os, pnt p) {
        os << "(" << p.x << ", " << p.y << ")";
        return os;
    }
};

struct params {
    pnt offset;
    pair<pnt, pnt> bounds;
};

vector<pnt> d;

params process(string s) {
    params res;
    res.bounds.first = pnt(0, 0);
    res.bounds.second = pnt(-1e9, -1e9);

    stringstream cmds(s);

    pnt cur;
    string cmd;
    while (cmds >> cmd) {
        int n = atoi(cmd.substr(1, string::npos).c_str());
        char c = cmd[0];

        int dx = 0, dy = 0;
        switch(c) {
        case 'U': dy = 1;  dx = 0; break;
        case 'D': dy = -1; dx = 0; break;
        case 'L': dy = 0;  dx = -1; break;
        case 'R': dy = 0;  dx = 1; break;
        };

        d.push_back(pnt(n * dx, n * dy));

        cur.x += n * dx;
        cur.y += n * dy;

        res.bounds.first.x = min(res.bounds.first.x, cur.x);
        res.bounds.first.y = min(res.bounds.first.y, cur.y);
        res.bounds.second.x = max(res.bounds.second.x, cur.x);
        res.bounds.second.y = max(res.bounds.second.y, cur.y);
    }

    res.offset = cur;

    return res;
}

int main() {
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);

    int n;
    cin >> n;

    for (int i = 0; i < n; i++) {
        d.clear();

        string s;
        getline(cin, s);
        getline(cin, s);

        pair<pnt, pnt> rect;
        cin >> rect.first.x >> rect.first.y >> rect.second.x >> rect.second.y;

        params p = process(s);

        int ans = 0;
        for (int x = rect.first.x; x <= rect.second.x; x++) {
            for (int y = rect.first.y; y <= rect.second.y; y++) {
                pnt cur;
                for (int i = 0; i < d.size(); i++) {
                    pnt next = cur + d[i];


                    pnt a(min(cur.x, next.x), min(cur.y, next.y));
                    pnt b(max(cur.x, next.x), max(cur.y, next.y));

                    int kx = 0;
                    int ky = 0;

                    if (p.offset.x != 0) {
                        kx = (x - a.x) / p.offset.x;

                        if (abs(x - b.x) > abs(x - a.x)) {
                            kx = (x - b.x) / p.offset.x;
                        }

                        ky = kx;
                    } else if (p.offset.y != 0) {
                        ky = (y - a.y) / p.offset.y;

                        if (abs(y - b.y) > abs(y - a.y)) {
                            ky = (y - b.y) / p.offset.y;
                        }

                        kx = ky;
                    }

                    // kx = max(kx, 0);
                    // ky = max(ky, 0);
                    if (kx < 0) {
                        ky += -kx;
                        kx = 0;
                    }
                    if (ky < 0) {
                        kx += -ky;
                        ky = 0;
                    }

                    // if (kx != ky && p.offset.x != 0 && p.offset.y != 0) {
                    //     break;
                    // }
                    if (kx != ky) {
                        break;
                    }

                    // if (kx < 0 || ky < 0) {
                    //     break;
                    // }


                    a += pnt(p.offset.x * kx, p.offset.y * ky);
                    b += pnt(p.offset.x * kx, p.offset.y * ky);

                    if (next.x == cur.x) {
                        if (a.x == x && a.y <= y && y <= b.y) {
                            ans++;
                            // cout << pnt(x, y) << endl;
                            // cout << "k: " << pnt(kx, ky) << endl;
                            break;
                        }
                    } else {
                        if (a.y == y && a.x <= x && x <= b.x) {
                            ans++;
                            // cout << pnt(x, y) << endl;
                            // cout << "k: " << pnt(kx, ky) << endl;
                            break;
                        }
                    }

                    cur = next;
                }

            }
        }

        cout << ans << endl;
    }
}